summaryrefslogtreecommitdiffstats
path: root/konqueror
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 18:13:27 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 18:13:27 -0600
commit68c175bf64155c578223561d9c3a1ad38d9424f8 (patch)
tree4d6496cfb0258364f480b508cb13658a77c34b31 /konqueror
parent472156a41b1348c714986c772759ad950fffbe75 (diff)
downloadtdebase-68c175bf64155c578223561d9c3a1ad38d9424f8.tar.gz
tdebase-68c175bf64155c578223561d9c3a1ad38d9424f8.zip
Rename KHTML and kiobuffer
Diffstat (limited to 'konqueror')
-rw-r--r--konqueror/DESIGN4
-rw-r--r--konqueror/about/Makefile.am2
-rw-r--r--konqueror/about/konq_aboutpage.cc4
-rw-r--r--konqueror/about/konq_aboutpage.h6
-rw-r--r--konqueror/keditbookmarks/updater.cpp2
-rw-r--r--konqueror/konq_mainwindow.cc2
-rw-r--r--konqueror/konq_viewmgr.cc2
-rw-r--r--konqueror/konqueror.kcfg58
-rw-r--r--konqueror/kttsplugin/Makefile.am2
-rw-r--r--konqueror/kttsplugin/tdehtmlkttsd.cpp18
-rw-r--r--konqueror/kttsplugin/tdehtmlkttsd.h12
-rw-r--r--konqueror/sidebar/web_module/Makefile.am2
-rw-r--r--konqueror/sidebar/web_module/TODO6
-rw-r--r--konqueror/sidebar/web_module/web_module.cpp2
-rw-r--r--konqueror/sidebar/web_module/web_module.h18
15 files changed, 70 insertions, 70 deletions
diff --git a/konqueror/DESIGN b/konqueror/DESIGN
index da257cb05..98c13d56d 100644
--- a/konqueror/DESIGN
+++ b/konqueror/DESIGN
@@ -19,7 +19,7 @@ at once, possibly using several modes. Each view is a KonqView.
The KonqView contains the child part, which can be :
- an icon view (KonqIconView)
- a list view / tree view (KonqListView/KonqTreeView)
-- an HTML view (KHTMLPart)
+- an HTML view (TDEHTMLPart)
- any other ReadOnlyPart with or without Browserextension
Where to find those classes
@@ -88,7 +88,7 @@ From the tdehtml side:
* Site with no frames: no problem, it just obeys to saveState/restoreState.
* Site with frames:
-KHTMLPart saves the whole structure (all frames, and their URL) in the
+TDEHTMLPart saves the whole structure (all frames, and their URL) in the
history buffer (saveState/restoreState).
Every time a frame changes its URL, we want a new item in the history.
But when this happens, since it's internal to tdehtml, konqueror wouldn't know
diff --git a/konqueror/about/Makefile.am b/konqueror/about/Makefile.am
index b8293c098..0a33f9bb7 100644
--- a/konqueror/about/Makefile.am
+++ b/konqueror/about/Makefile.am
@@ -3,7 +3,7 @@ kde_module_LTLIBRARIES = konq_aboutpage.la
INCLUDES = -I$(srcdir)/.. -I$(top_srcdir)/libkonq $(all_includes)
konq_aboutpage_la_SOURCES = konq_aboutpage.cc
konq_aboutpage_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module
-konq_aboutpage_la_LIBADD = $(LIB_KHTML)
+konq_aboutpage_la_LIBADD = $(LIB_TDEHTML)
kde_services_DATA = konq_aboutpage.desktop
kde_servicetypes_DATA = konqaboutpage.desktop
diff --git a/konqueror/about/konq_aboutpage.cc b/konqueror/about/konq_aboutpage.cc
index ab602eb94..7b608fe7c 100644
--- a/konqueror/about/konq_aboutpage.cc
+++ b/konqueror/about/konq_aboutpage.cc
@@ -429,7 +429,7 @@ TQString KonqAboutPageFactory::plugins()
KonqAboutPage::KonqAboutPage( //KonqMainWindow *
TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name )
- : KHTMLPart( parentWidget, widgetName, parent, name, BrowserViewGUI )
+ : TDEHTMLPart( parentWidget, widgetName, parent, name, BrowserViewGUI )
{
//m_mainWindow = mainWindow;
TQTextCodec* codec = TDEGlobal::locale()->codecForEncoding();
@@ -552,7 +552,7 @@ void KonqAboutPage::urlSelected( const TQString &url, int button, int state, con
return;
}
- KHTMLPart::urlSelected( url, button, state, target, _args );
+ TDEHTMLPart::urlSelected( url, button, state, target, _args );
}
#include "konq_aboutpage.moc"
diff --git a/konqueror/about/konq_aboutpage.h b/konqueror/about/konq_aboutpage.h
index d9513d5d3..a4192d570 100644
--- a/konqueror/about/konq_aboutpage.h
+++ b/konqueror/about/konq_aboutpage.h
@@ -4,7 +4,7 @@
#include <tdeparts/factory.h>
#include <tdehtml_part.h>
-class KHTMLPart;
+class TDEHTMLPart;
class TDEInstance;
class KonqAboutPageFactory : public KParts::Factory
@@ -32,7 +32,7 @@ private:
static TQString *s_launch_html, *s_intro_html, *s_specs_html, *s_tips_html, *s_plugins_html;
};
-class KonqAboutPage : public KHTMLPart
+class KonqAboutPage : public TDEHTMLPart
{
Q_OBJECT
public:
@@ -54,7 +54,7 @@ protected:
private:
void serve( const TQString&, const TQString& );
- KHTMLPart *m_doc;
+ TDEHTMLPart *m_doc;
//KonqMainWindow *m_mainWindow;
TQString m_htmlDoc;
TQString m_what;
diff --git a/konqueror/keditbookmarks/updater.cpp b/konqueror/keditbookmarks/updater.cpp
index 6d14d89ae..56214e3d0 100644
--- a/konqueror/keditbookmarks/updater.cpp
+++ b/konqueror/keditbookmarks/updater.cpp
@@ -147,7 +147,7 @@ FavIconWebGrabber::FavIconWebGrabber(KParts::ReadOnlyPart *part, const KURL &url
// kdDebug() << "FavIconWebGrabber::FavIconWebGrabber starting TDEIO::get() " << url << endl;
-// the use of KIO rather than directly using KHTML is to allow silently abort on error
+// the use of KIO rather than directly using TDEHTML is to allow silently abort on error
TDEIO::Job *job = TDEIO::get(m_url, false, false);
job->addMetaData( TQString("cookies"), TQString("none") );
diff --git a/konqueror/konq_mainwindow.cc b/konqueror/konq_mainwindow.cc
index c5e1d7d7a..5ad4c6eae 100644
--- a/konqueror/konq_mainwindow.cc
+++ b/konqueror/konq_mainwindow.cc
@@ -4815,7 +4815,7 @@ void KonqMainWindow::slotPopupMenu( KXMLGUIClient *client, const TQPoint &_globa
viewURL,
popupMenuCollection,
m_pMenuNew,
- // This parent ensures that if the part destroys itself (e.g. KHTML redirection),
+ // This parent ensures that if the part destroys itself (e.g. TDEHTML redirection),
// it will close the popupmenu
currentView->part()->widget(),
kpf,
diff --git a/konqueror/konq_viewmgr.cc b/konqueror/konq_viewmgr.cc
index f765006b5..b2ff4b475 100644
--- a/konqueror/konq_viewmgr.cc
+++ b/konqueror/konq_viewmgr.cc
@@ -1460,7 +1460,7 @@ void KonqViewManager::loadItem( TDEConfig &cfg, KonqFrameContainerBase *parent,
TQString serviceType;
TQString serviceName;
if ( name == "empty" ) {
- // An empty profile is an empty KHTML part. Makes all KHTML actions available, avoids crashes,
+ // An empty profile is an empty TDEHTML part. Makes all TDEHTML actions available, avoids crashes,
// makes it easy to DND a URL onto it, and makes it fast to load a website from there.
serviceType = "text/html";
serviceName = "html";
diff --git a/konqueror/konqueror.kcfg b/konqueror/konqueror.kcfg
index 0b0b9f640..60a487b97 100644
--- a/konqueror/konqueror.kcfg
+++ b/konqueror/konqueror.kcfg
@@ -205,55 +205,55 @@
<group name="HTML Settings" >
<!-- appearance.cpp -->
- <entry key="MediumFontSize" type="Int"> <!--KHTML-->
+ <entry key="MediumFontSize" type="Int"> <!--TDEHTML-->
<default>12</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="MinimumFontSize" type="Int"> <!--KHTML-->
+ <entry key="MinimumFontSize" type="Int"> <!--TDEHTML-->
<default code="true">HTML_DEFAULT_MIN_FONT_SIZE</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="Fonts" type="StringList"> <!--KHTML-->
+ <entry key="Fonts" type="StringList"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="DefaultEncoding" type="String"> <!--KHTML-->
+ <entry key="DefaultEncoding" type="String"> <!--TDEHTML-->
<default code="true">TQString()</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
<!-- htmlopts.cpp -->
- <entry key="ChangeCursor" type="Bool"> <!--KHTML-->
+ <entry key="ChangeCursor" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry name="HtmlUnderlineLinks" key="UnderlineLinks" type="Bool"> <!--KHTML-->
+ <entry name="HtmlUnderlineLinks" key="UnderlineLinks" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="HoverLinks" type="Bool"> <!--KHTML-->
+ <entry key="HoverLinks" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="AutoLoadImages" type="Bool"> <!--KHTML-->
+ <entry key="AutoLoadImages" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="ShowAnimations" type="String"> <!--KHTML-->
+ <entry key="ShowAnimations" type="String"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
@@ -264,13 +264,13 @@
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="FormCompletion" type="Bool"> <!--KHTML-->
+ <entry key="FormCompletion" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="MaxFormCompletionItems" type="Int"> <!--KHTML-->
+ <entry key="MaxFormCompletionItems" type="Int"> <!--TDEHTML-->
<default>10</default>
<label></label>
<whatsthis></whatsthis>
@@ -284,18 +284,18 @@
<!-- Can't find writeEntry -->
</entry>
<!-- KDELIBS/tdehtml_part.cpp -->
- <entry key="AutomaticDetectionLanguage" type="Int"> <!--KHTML-->
+ <entry key="AutomaticDetectionLanguage" type="Int"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
<!-- KDELIBS/tdehtml_settings.cpp -->
- <entry key="EnforceDefaultCharset" type="Bool"> <!--KHTML-->
+ <entry key="EnforceDefaultCharset" type="Bool"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
<!-- Can't find writeEntry -->
</entry>
<!-- kcmcss.cpp KDELIBS/tdehtml_settings.cpp -->
- <entry key="UserStyleSheetEnabled" type="Bool"> <!--KHTML-->
+ <entry key="UserStyleSheetEnabled" type="Bool"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
@@ -324,13 +324,13 @@
<group name="MainView Settings" >
<!-- htmlopts.cpp -->
- <entry key="OpenMiddleClick" type="Bool"> <!--KHTML-->
+ <entry key="OpenMiddleClick" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="BackRightClick" type="Bool"> <!--KHTML-->
+ <entry key="BackRightClick" type="Bool"> <!--TDEHTML-->
<default>false</default>
<label></label>
<whatsthis></whatsthis>
@@ -414,7 +414,7 @@ PATH_JAVA
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="JavaDomains" type="StringList"> <!--KHTML-->
+ <entry key="JavaDomains" type="StringList"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
@@ -435,61 +435,61 @@ PATH_JAVA
<!-- checked -->
</entry>
<!-- jsopts.cpp -->
- <entry key="ECMADomains" type="StringList"> <!--KHTML-->
+ <entry key="ECMADomains" type="StringList"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="ECMADomainSettings" type="StringList"> <!--KHTML-->
+ <entry key="ECMADomainSettings" type="StringList"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="ReportJavaScriptErrors" type="Bool"> <!--KHTML-->
+ <entry key="ReportJavaScriptErrors" type="Bool"> <!--TDEHTML-->
<default>false</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
- <entry key="EnableJavaScriptDebug" type="Bool"> <!--KHTML-->
+ <entry key="EnableJavaScriptDebug" type="Bool"> <!--TDEHTML-->
<default>false</default>
<label></label>
<whatsthis></whatsthis>
<!-- checked -->
</entry>
<!-- jspolicies.cpp -->
- <entry key="EnableJavaScript" type="Bool"> <!--KHTML-->
+ <entry key="EnableJavaScript" type="Bool"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
- <entry key="WindowOpenPolicy" type="UInt"> <!--KHTML-->
+ <entry key="WindowOpenPolicy" type="UInt"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
- <entry key="WindowResizePolicy" type="UInt"> <!--KHTML-->
+ <entry key="WindowResizePolicy" type="UInt"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
- <entry key="WindowMovePolicy" type="UInt"> <!--KHTML-->
+ <entry key="WindowMovePolicy" type="UInt"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
- <entry key="WindowFocusPolicy" type="UInt"> <!--KHTML-->
+ <entry key="WindowFocusPolicy" type="UInt"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
- <entry key="WindowStatusPolicy" type="UInt"> <!--KHTML-->
+ <entry key="WindowStatusPolicy" type="UInt"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
<!-- pluginopts.cpp -->
- <entry key="EnablePlugins" type="Bool"> <!--KHTML-->
+ <entry key="EnablePlugins" type="Bool"> <!--TDEHTML-->
<default>true</default>
<label></label>
<whatsthis></whatsthis>
</entry>
- <entry key="PluginDomains" type="StringList"> <!--KHTML-->
+ <entry key="PluginDomains" type="StringList"> <!--TDEHTML-->
<label></label>
<whatsthis></whatsthis>
</entry>
diff --git a/konqueror/kttsplugin/Makefile.am b/konqueror/kttsplugin/Makefile.am
index d82a56fc2..faa445143 100644
--- a/konqueror/kttsplugin/Makefile.am
+++ b/konqueror/kttsplugin/Makefile.am
@@ -5,7 +5,7 @@ METASOURCES = AUTO
kde_module_LTLIBRARIES = libtdehtmlkttsdplugin.la
libtdehtmlkttsdplugin_la_SOURCES = tdehtmlkttsd.cpp
-libtdehtmlkttsdplugin_la_LIBADD = $(LIB_KHTML)
+libtdehtmlkttsdplugin_la_LIBADD = $(LIB_TDEHTML)
libtdehtmlkttsdplugin_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
pluginsdir = $(kde_datadir)/tdehtml/kpartplugins
diff --git a/konqueror/kttsplugin/tdehtmlkttsd.h b/konqueror/kttsplugin/tdehtmlkttsd.h
index f42c9b03e..f9e606c16 100644
--- a/konqueror/kttsplugin/tdehtmlkttsd.h
+++ b/konqueror/kttsplugin/tdehtmlkttsd.h
@@ -14,8 +14,8 @@
***************************************************************************/
-#ifndef KHTMLKTTSD_H
-#define KHTMLKTTSD_H
+#ifndef TDEHTMLKTTSD_H
+#define TDEHTMLKTTSD_H
#include <tdeparts/plugin.h>
@@ -23,9 +23,9 @@ class KURL;
class TDEInstance;
/**
- * KHTML KParts Plugin
+ * TDEHTML KParts Plugin
*/
-class KHTMLPluginKTTSD : public KParts::Plugin
+class TDEHTMLPluginKTTSD : public KParts::Plugin
{
Q_OBJECT
public:
@@ -33,12 +33,12 @@ public:
/**
* Construct a new KParts plugin.
*/
- KHTMLPluginKTTSD( TQObject* parent, const char* name, const TQStringList& );
+ TDEHTMLPluginKTTSD( TQObject* parent, const char* name, const TQStringList& );
/**
* Destructor.
*/
- virtual ~KHTMLPluginKTTSD();
+ virtual ~TDEHTMLPluginKTTSD();
public slots:
void slotReadOut();
};
diff --git a/konqueror/sidebar/web_module/Makefile.am b/konqueror/sidebar/web_module/Makefile.am
index 64675d351..a55213aab 100644
--- a/konqueror/sidebar/web_module/Makefile.am
+++ b/konqueror/sidebar/web_module/Makefile.am
@@ -6,7 +6,7 @@ METASOURCES = AUTO
konqsidebar_web_la_SOURCES = web_module.cpp
konqsidebar_web_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN)
-konqsidebar_web_la_LIBADD = $(LIB_KPARTS) $(LIB_KHTML) ../libkonqsidebarplugin.la ../../../libkonq/libkonq.la
+konqsidebar_web_la_LIBADD = $(LIB_KPARTS) $(LIB_TDEHTML) ../libkonqsidebarplugin.la ../../../libkonq/libkonq.la
#plugindir=$(kde_datadir)/konqsidebartng/entries
#plugin_DATA=websidebar.desktop
diff --git a/konqueror/sidebar/web_module/TODO b/konqueror/sidebar/web_module/TODO
index abf3260f9..6f268cbed 100644
--- a/konqueror/sidebar/web_module/TODO
+++ b/konqueror/sidebar/web_module/TODO
@@ -1,6 +1,6 @@
- Apparently _content works everywhere in Mozilla. Maybe this should go into
-KHTMLPart afterall. That would solve the form post problem too.
+TDEHTMLPart afterall. That would solve the form post problem too.
- Forms don't work. I don't know if they will for a long time since we can't
- really filter them with KHTML.
+ really filter them with TDEHTML.
- Allow setting the useragent (only do this in a clean fashion!!)
-- Double check the KHTML extensions for security implications.
+- Double check the TDEHTML extensions for security implications.
diff --git a/konqueror/sidebar/web_module/web_module.cpp b/konqueror/sidebar/web_module/web_module.cpp
index 1386ee0a7..f0705ae3a 100644
--- a/konqueror/sidebar/web_module/web_module.cpp
+++ b/konqueror/sidebar/web_module/web_module.cpp
@@ -35,7 +35,7 @@
KonqSideBarWebModule::KonqSideBarWebModule(TDEInstance *instance, TQObject *parent, TQWidget *widgetParent, TQString &desktopName, const char* name)
: KonqSidebarPlugin(instance, parent, widgetParent, desktopName, name)
{
- _htmlPart = new KHTMLSideBar(universalMode());
+ _htmlPart = new TDEHTMLSideBar(universalMode());
connect(_htmlPart, TQT_SIGNAL(reload()), this, TQT_SLOT(reload()));
connect(_htmlPart, TQT_SIGNAL(completed()), this, TQT_SLOT(pageLoaded()));
connect(_htmlPart,
diff --git a/konqueror/kttsplugin/tdehtmlkttsd.cpp b/konqueror/kttsplugin/tdehtmlkttsd.cpp
index 80b756a8b..6d643dd9b 100644
--- a/konqueror/kttsplugin/tdehtmlkttsd.cpp
+++ b/konqueror/kttsplugin/tdehtmlkttsd.cpp
@@ -33,7 +33,7 @@
#include <dcopclient.h>
#include <ktrader.h>
-KHTMLPluginKTTSD::KHTMLPluginKTTSD( TQObject* parent, const char* name, const TQStringList& )
+TDEHTMLPluginKTTSD::TDEHTMLPluginKTTSD( TQObject* parent, const char* name, const TQStringList& )
: Plugin( parent, name )
{
// If KTTSD is not installed, hide action.
@@ -46,17 +46,17 @@ KHTMLPluginKTTSD::KHTMLPluginKTTSD( TQObject* parent, const char* name, const TQ
actionCollection(), "tools_kttsd" );
}
else
- kdDebug() << "KHTMLPLuginKTTSD::KHTMLPluginKTTSD: KTrader did not find KTTSD." << endl;
+ kdDebug() << "TDEHTMLPLuginKTTSD::TDEHTMLPluginKTTSD: KTrader did not find KTTSD." << endl;
}
-KHTMLPluginKTTSD::~KHTMLPluginKTTSD()
+TDEHTMLPluginKTTSD::~TDEHTMLPluginKTTSD()
{
}
-void KHTMLPluginKTTSD::slotReadOut()
+void TDEHTMLPluginKTTSD::slotReadOut()
{
- // The parent is assumed to be a KHTMLPart
- if ( !parent()->inherits("KHTMLPart") )
+ // The parent is assumed to be a TDEHTMLPart
+ if ( !parent()->inherits("TDEHTMLPart") )
TQMessageBox::warning( 0, i18n( "Cannot Read source" ),
i18n( "You cannot read anything except web pages with\n"
"this plugin, sorry." ));
@@ -91,7 +91,7 @@ void KHTMLPluginKTTSD::slotReadOut()
reply >> supportsXhtml;
}
- KHTMLPart *part = (KHTMLPart *) parent();
+ TDEHTMLPart *part = (TDEHTMLPart *) parent();
TQString query;
if (supportsXhtml)
@@ -116,7 +116,7 @@ void KHTMLPluginKTTSD::slotReadOut()
else
query = part->htmlDocument().body().innerText().string();
}
- // kdDebug() << "KHTMLPluginKTTSD::slotReadOut: query = " << query << endl;
+ // kdDebug() << "TDEHTMLPluginKTTSD::slotReadOut: query = " << query << endl;
dataBuf.at(0); // reset data
arg << query << "";
@@ -133,6 +133,6 @@ void KHTMLPluginKTTSD::slotReadOut()
}
}
-K_EXPORT_COMPONENT_FACTORY( libtdehtmlkttsdplugin, KGenericFactory<KHTMLPluginKTTSD>("tdehtmlkttsd") )
+K_EXPORT_COMPONENT_FACTORY( libtdehtmlkttsdplugin, KGenericFactory<TDEHTMLPluginKTTSD>("tdehtmlkttsd") )
#include "tdehtmlkttsd.moc"
diff --git a/konqueror/sidebar/web_module/web_module.h b/konqueror/sidebar/web_module/web_module.h
index b7538bff3..3a43a54d0 100644
--- a/konqueror/sidebar/web_module/web_module.h
+++ b/konqueror/sidebar/web_module/web_module.h
@@ -28,18 +28,18 @@
#include <tqobject.h>
-// A wrapper for KHTMLPart to make it behave the way we want it to.
-class KHTMLSideBar : public KHTMLPart
+// A wrapper for TDEHTMLPart to make it behave the way we want it to.
+class TDEHTMLSideBar : public TDEHTMLPart
{
Q_OBJECT
public:
- KHTMLSideBar(bool universal) : KHTMLPart() {
+ TDEHTMLSideBar(bool universal) : TDEHTMLPart() {
setStatusMessagesEnabled(false);
setMetaRefreshEnabled(true);
setJavaEnabled(false);
setPluginsEnabled(false);
- setFormNotification(KHTMLPart::Only);
+ setFormNotification(TDEHTMLPart::Only);
connect(this,
TQT_SIGNAL(formSubmitNotification(const char*,const TQString&,const TQByteArray&,const TQString&,const TQString&,const TQString&)),
this,
@@ -69,7 +69,7 @@ class KHTMLSideBar : public KHTMLPart
TQT_SLOT(showMenu(const TQString&, const TQPoint&)));
}
- virtual ~KHTMLSideBar() {}
+ virtual ~TDEHTMLSideBar() {}
signals:
void submitFormRequest(const char*,const TQString&,const TQByteArray&,const TQString&,const TQString&,const TQString&);
@@ -102,7 +102,7 @@ class KHTMLSideBar : public KHTMLPart
openURL(completeURL(url));
return;
}
- KHTMLPart::urlSelected(url,button,state,_target,args);
+ TDEHTMLPart::urlSelected(url,button,state,_target,args);
}
protected slots:
@@ -149,10 +149,10 @@ class KHTMLSideBar : public KHTMLPart
emit submitFormRequest(action, u, formData,
target, contentType, boundary);
} else if (t.isEmpty() || t == "_self") {
- setFormNotification(KHTMLPart::NoNotification);
+ setFormNotification(TDEHTMLPart::NoNotification);
submitFormProxy(action, u, formData, target,
contentType, boundary);
- setFormNotification(KHTMLPart::Only);
+ setFormNotification(TDEHTMLPart::Only);
}
}
private:
@@ -192,7 +192,7 @@ class KonqSideBarWebModule : public KonqSidebarPlugin
void reload();
private:
- KHTMLSideBar *_htmlPart;
+ TDEHTMLSideBar *_htmlPart;
KURL _url;
int reloadTimeout;
TQString _desktopName;